==> tibet-5.3.6.tgz: package/README.md <==
## TIBET&#8482; -- The Desktop-to-Cloud Platform&#8482;


                                     ,`
                              __,~//`
           ,///,_       .~///////'`
               '//,   ///'`
                  '/_/'
                    `
            /////////////////     /////////////// ///
            `//'````````///      `//'```````````  '''
            ,/`          //      ,/'
           ,/___          /'    ,/_____
          ///////;;,_     //   ,/////////;,_
                   `'//,  '/            `'///,_
                       `'/,/                '//,
                          `/,                  `/,
                            '                   `/
                                                 '/
                                                  /
                                                  '

<br/>

Build desktop applications, web applications, Cloud APIs, and more with TIBET.

We like to say TIBET is **The Sum Of The Parts, Not Some Of The Parts&#8482;**

TIBET includes a full client stack, full server stack, and full tool chain. All fully-integrated, all fully-supported. See <a href="https://www.technicalpursuit.com">technicalpursuit.com</a> for details.

## Primary Features

### Desktop-To-Cloud
<ul>
<li>Electron desktop application framing.</li>
<li>Express API server, mocks, and tools.</li>
<li>NodeJS devops-lifecycle command line.</li>
</ul>

### Low-Code / No-Code
<ul>
<li>Low-Code application authoring.</li>
<li>No-Code component consumption.</li>
<li>Immersive, iterative, in-situ IDE.</li>
</ul>

### Full Client & Server Stack
<ul>
<li>Layered MVC/MVVM application platform.</li>
<li>Secure, pluggable API and mock data server.</li>
<li>Extensible IDE and NodeJS command tools.</li>
</ul>

<br/>
<br/>
<img alt="Installation" src="./lib/media/disk.png" width="64px" height="64px"/>
## Installation

Install TIBET via `npm install -g` and `tibet init`:

```
npm install -g tibet

tibet init
```

See the <a href="https://github.com/TechnicalPursuit/TIBET/blob/master/INSTALL.md#installation">full installation instructions</a> if you want to run TIBET via Docker, or are interested in installing a development fork via Git.

**Once your installation completes check out the <a href="https://www.technicalpursuit.com/docs/quickstart.html">TIBET Quickstart Guide</a>.**

<br/>
<br/>
<img alt="Documentation" src="./lib/media/music.png" width="64px" height="64px"/>
## Documentation

Documentation for TIBET can be found at <a href="https://www.technicalpursuit.com/docs">technicalpursuit.com/docs</a>:

<ul>
<li>Full Client Stack</li>
<li>Full Server Stack</li>
<li>TIBET Power Tools</li>
<li>TIBET Manpages</li>
<li>API Documentation</li>
<li>Special-Interest Topics</li>
<li>Standards & Conventions</li>
</ul>

<br/>
<br/>
<img alt="Open Source License" src="./lib/media/osi_logo.png" width="64px" height="64px"/>
## License

TIBET is Open Source under the OSI-approved <a
href="http://opensource.org/licenses/RPL-1.5">Reciprocal Public License
(RPL)</a>.

Visit <a href="https://www.technicalpursuit.com/">https://www.technicalpursuit.com</a> for specific licensing options.
<br/>

---

<img alt="The Pup" src="./lib/media/thepup.jpg" width="92px" height="138px"/>

==> tibet-6.0.1.tgz: package/README.md <==
## TIBET&#8482; -- The Desktop-to-Cloud Platform&#8482;


                                     ,`
                              __,~//`
           ,///,_       .~///////'`
               '//,   ///'`
                  '/_/'
                    `
            /////////////////     /////////////// ///
            `//'````````///      `//'```````````  '''
            ,/`          //      ,/'
           ,/___          /'    ,/_____
          ///////;;,_     //   ,/////////;,_
                   `'//,  '/            `'///,_
                       `'/,/                '//,
                          `/,                  `/,
                            '                   `/
                                                 '/
                                                  /
                                                  '

<br/>

Build desktop applications, web applications, Cloud APIs, and more with TIBET.

We like to say TIBET is **The Sum Of The Parts, Not Some Of The Parts&#8482;**

TIBET includes a full client stack, full server stack, and full tool chain. See <a href="https://www.technicalpursuit.com">technicalpursuit.com</a> for details.

## Primary Features

### Desktop-To-Cloud
<ul>
<li>Electron desktop application framing.</li>
<li>Express API server, mocks, and tools.</li>
<li>NodeJS devops-lifecycle command line.</li>
</ul>

### Low-Code / No-Code
<ul>
<li>Low-Code application authoring.</li>
<li>No-Code component consumption.</li>
<li>Immersive, iterative, in-situ IDE.</li>
</ul>

### Full Client & Server Stack
<ul>
<li>Layered MVC/MVVM application platform.</li>
<li>Secure, pluggable API and mock data server.</li>
<li>Extensible IDE and NodeJS command tools.</li>
</ul>

<br/>
<br/>
<img alt="Installation" src="./lib/media/disk.png" width="64px" height="64px"/>
## Installation

Install TIBET via `npm install -g` and `tibet init`:

```
npm install -g tibet

tibet init
```

See the <a href="https://github.com/TechnicalPursuit/TIBET/blob/master/INSTALL.md#installation">full installation instructions</a> if you want to run TIBET via Docker, or are interested in installing a development fork via Git.

**Once your installation completes check out the <a href="https://www.technicalpursuit.com/docs/quickstart.html">TIBET Quickstart Guide</a>.**

<br/>
<br/>
<img alt="Documentation" src="./lib/media/music.png" width="64px" height="64px"/>
## Documentation

Documentation for TIBET can be found at <a href="https://www.technicalpursuit.com/docs">technicalpursuit.com/docs</a>:

<ul>
<li>Full Client Stack</li>
<li>Full Server Stack</li>
<li>TIBET Power Tools</li>
<li>TIBET Manpages</li>
<li>API Documentation</li>
<li>Special-Interest Topics</li>
<li>Standards & Conventions</li>
</ul>

<br/>
<br/>
<img alt="Open Source License" src="./lib/media/osi_logo.png" width="64px" height="64px"/>
## License

TIBET is Open Source under the OSI-approved <a
href="http://opensource.org/licenses/RPL-1.5">Reciprocal Public License
(RPL)</a>.

Visit <a href="https://www.technicalpursuit.com/">https://www.technicalpursuit.com</a> for specific licensing options.
<br/>

---

<img alt="The Pup" src="./lib/media/thepup.jpg" width="92px" height="138px"/>
